==> carmel-foundation-stack-0.2.21.tgz: package/layouts/default/index.js <==
import React, { Component } from 'react'
import './style.scss'
import Redirect   from 'react-router/Redirect'

import {
  Header,
  Layout,
  Drawer,
  Content,
  Navigation,
  Footer,
  FooterSection,
  FooterLinkList,
  Button
} from 'react-mdl'

export default class MainLayout extends Component {

  constructor(props) {
    super(props)
    this.state = {}
  }

  get menu () {
    return this.props.menu.map(menuItem => {
      return (<a key={menuItem.id} href={menuItem.link} styleName="menuItem"> { menuItem.title } </a>)
    })
  }

  onLogout() {
    localStorage.removeItem('@carmel:authToken')
    this.setState({ loggedOut: true })
  }


  get actionMenu () {
    if (this.props.session.isLoggedIn) {
      return (<Button key={9999} raised ripple accent style={{marginLeft: "1rem"}}
                onClick={this.onLogout.bind(this)}>
        Logout
      </Button>)
    }
  }

  renderHeader() {
    return (<Header transparent title={this.props.info.title} styleName="header">
      <Navigation styleName="menu">
        { this.menu }
      </Navigation>
      { this.actionMenu}
    </Header>)
  }

  renderDrawer() {
    return (<Drawer title={this.props.info.title}>
      <Navigation>
        { this.menu }
      </Navigation>
    </Drawer>)
  }

  render () {
    if (this.state.loggedOut) {
      window.location.reload()
      return (<Redirect to="/"/>)
    }

    return (<Layout fixedHeader>
            { this.renderHeader() }
            { this.renderDrawer() }
            <Content>
              <div styleName="container">
                { this.props.children}
              </div>
            </Content>
      </Layout>)
  }
}

==> carmel-foundation-stack-0.4.0.tgz: package/layouts/default/index.js <==
import React, { Component } from 'react'
import './style.scss'
import Redirect   from 'react-router/Redirect'

import {
  Header,
  Layout,
  Drawer,
  Content,
  Navigation,
  Footer,
  FooterSection,
  FooterLinkList,
  Button
} from 'react-mdl'

export default class MainLayout extends Component {

  constructor(props) {
    super(props)
    this.state = {}
  }

  get menu () {
    return this.props.menu.map(menuItem => {
      return (<a key={menuItem.id} href={menuItem.link} styleName="menuItem"> { menuItem.title } </a>)
    })
  }

  onLogout() {
    localStorage.removeItem('@carmel:authToken')
    this.setState({ loggedOut: true })
  }

  get actionMenu () {
    if (this.props.session.isLoggedIn) {
      return (<Button key={9999} raised ripple accent style={{marginLeft: "1rem"}}
                onClick={this.onLogout.bind(this)}>
        Logout
      </Button>)
    }
  }

  renderLogo() {
    return (<a href="/" styleName="logo">
            <img src="/images/logo.jpg"/>
    </a>)
  }

  renderHeader() {
    return (<Header transparent styleName="header">
    { this.renderLogo() }
      <Navigation styleName="menu">
        { this.menu }
      </Navigation>
      { this.actionMenu}
    </Header>)
  }

  renderDrawer() {
    return (<Drawer title={this.props.info.title}>
      <Navigation>
        { this.menu }
      </Navigation>
    </Drawer>)
  }

  render () {
    if (this.state.loggedOut) {
      window.location.reload()
      return (<Redirect to="/"/>)
    }

    return (<Layout fixedHeader>
            { this.renderHeader() }
            { this.renderDrawer() }
            <Content>
              <div styleName="container">
                { this.props.children}
              </div>
            </Content>
      </Layout>)
  }
}
